==> aloe-1.3.tar.gz: aloe-1.3/modules/gen_viterbi/src/module_imp.c <==
/** ALOE headers
 */
#include <phal_sw_api.h>
#include <swapi_utils.h>

#include "typetools.h"

#include "itf_types.h"
#include "inputs.h"
#include "outputs.h"
#include "stats.h"


int longblock,longinblock,numblocks;
int configured;

int iterations;

unsigned char symbols[INPUT_MAX_DATA];
char output_bits[8*INPUT_MAX_DATA];

int mettab[2][256];

int process_input(int len) {
    int l,i;
    int rpm,wpm;
    char *input=input_data;
    char *output=output_bits;
    unsigned long metric;

 /*    if (len!=(RATE*longblock+TOTALTAIL)*numblocks) {
        Log("VITERBI: Invalid input length: longcb %d numcb %d len %d\n",longblock,numblocks,len);
        return 0;
    }
*/

    /* for each codeblock */
    rpm=0;
    wpm=0;
    for (l=0;l<numblocks;l++) {
        for (i=0;i<longinblock;i++) {
            symbols[i]=(unsigned char) (input[rpm+i]+128);
        }
        
        viterbi(&metric,output_data,symbols,longblock,mettab,0,0,
                ctrlpkt.CCcoderate,ctrlpkt.K,ctrlpkt.poly);

        rpm+=longinblock;
        wpm+=longblock;
    }

    /* send throught output */
    SendItf(0,typeSizeArray(TYPE_BITSTREAM,wpm));

    return 1;
}

int process_control(int len) {
    configured=1;
    longinblock=(ctrlpkt.long_block+ctrlpkt.K-1)*ctrlpkt.CCcoderate;
    longblock=ctrlpkt.long_block;
    numblocks=ctrlpkt.num_blocks;

    /** @todo variable EbNo */
    Log("VITERBI: longin=%d longcb=%d numcb=%d\n",longinblock,longblock,numblocks);
}

/** Run function.
 * @return 1 if ok, 0 if error
 */
int RunCustom()
{
    return 1;
}

int InitCustom()
{
    configured=0;
    numblocks=0;
    longblock=0;
    gen_met(mettab,80,0.39,0.,4);
    Log("metric table range %d to %d\n",mettab[0][0],mettab[1][0]);
    return 1;
}

void ConfigInterfaces(){}

==> aloe-1.4.5.tar.gz: aloe-1.4.5/modules/gen_viterbi/src/module_imp.c <==
/** ALOE headers
 */
#include <phal_sw_api.h>
#include <swapi_utils.h>

#include "typetools.h"

#include "itf_types.h"
#include "inputs.h"
#include "outputs.h"
#include "stats.h"


int longblock,longinblock,numblocks;
int configured;

int iterations;

unsigned char symbols[INPUT_MAX_DATA];
char output_bits[8*INPUT_MAX_DATA];

int mettab[2][256];

int process_input(int len) {
    int l,i;
    int rpm,wpm;
    char *input=input_data;
    char *output=output_bits;
    unsigned long metric;

      

    /* for each codeblock */
//    longinblock=1920;
    rpm=0;
    wpm=0;
    for (l=0;l<numblocks;l++) {
        for (i=0;i<longinblock;i++) {
            symbols[i]=(unsigned char) (input[rpm+i]+128);
         }
        
        viterbi(&metric,output_data,symbols,longblock,mettab,0,0,
                ctrlpkt.CCcoderate,ctrlpkt.K,ctrlpkt.poly);

        rpm+=longinblock;
        wpm+=longblock;
    }

    /* send throught output */
    SendItf(0,typeSizeArray(TYPE_BITSTREAM,wpm));

    return 1;
}

int process_control(int len) {
    configured=1;
    longinblock=(ctrlpkt.long_block+ctrlpkt.K-1)*ctrlpkt.CCcoderate;
    longblock=ctrlpkt.long_block;
    numblocks=ctrlpkt.num_blocks;
    printf("O---->GENVITERBI long_bloc=%d, numblocks=%d rate=%.2f K=%d\n",
            ctrlpkt.long_block, ctrlpkt.num_blocks,\
            (float) 1/ctrlpkt.CCcoderate, ctrlpkt.K);


    /** @todo variable EbNo */
    gen_met(mettab,80,0.39,0.,4);
    printf("O---->metric table range %d to %d\n",mettab[0][0],mettab[1][0]);
    xprintf("O---->VITERBI: longin=%d longcb=%d numcb=%d\n",longinblock,longblock,numblocks);
return(1);
}

/** Run function.
 * @return 1 if ok, 0 if error
 */
int RunCustom()
{
    return 1;
}

int InitCustom()
{
    configured=0;
    numblocks=0;
    longblock=0;
    return 1;
}

void ConfigInterfaces(){}
